@@ -9,17 +9,23 @@ __all__ = [
     "GridStateFromFileWithForecastsWithMaintenance",
     "GridStateFromFileWithForecastsWithoutMaintenance",
     "ReadPypowNetData",
-    "FromNPY"
+    "FromNPY",
+    "FromChronix2grid"
 ]
 
 from grid2op.Chronics.chronicsHandler import ChronicsHandler
 from grid2op.Chronics.changeNothing import ChangeNothing
 from grid2op.Chronics.gridValue import GridValue
 from grid2op.Chronics.gridStateFromFile import GridStateFromFile
-from grid2op.Chronics.gridStateFromFileWithForecasts import GridStateFromFileWithForecasts
+from grid2op.Chronics.gridStateFromFileWithForecasts import (
+    GridStateFromFileWithForecasts,
+)
 from grid2op.Chronics.multiFolder import Multifolder
 from grid2op.Chronics.readPypowNetData import ReadPypowNetData
 from grid2op.Chronics.GSFFWFWM import GridStateFromFileWithForecastsWithMaintenance
-from grid2op.Chronics.fromFileWithoutMaintenance import GridStateFromFileWithForecastsWithoutMaintenance
+from grid2op.Chronics.fromFileWithoutMaintenance import (
+    GridStateFromFileWithForecastsWithoutMaintenance,
+)
 from grid2op.Chronics.multifolderWithCache import MultifolderWithCache
 from grid2op.Chronics.fromNPY import FromNPY
+from grid2op.Chronics.fromChronix2grid import FromChronix2grid
