@@ -7,6 +7,7 @@
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
 
 import os
+import warnings
 import numpy as np
 import copy
 
@@ -171,8 +172,12 @@ class MultiMixEnvironment(GridObjects, RandomObject):
         # Special case handling for backend
         # TODO: with backend.copy() instead !
         backendClass = None
+        backend_kwargs = {}
         if "backend" in kwargs:
             backendClass = type(kwargs["backend"])
+            if hasattr(kwargs["backend"], "_my_kwargs"):
+                # was introduced in grid2op 1.7.1
+                backend_kwargs = kwargs["backend"]._my_kwargs
             del kwargs["backend"]
 
         # Inline import to prevent cyclical import
@@ -191,9 +196,21 @@ class MultiMixEnvironment(GridObjects, RandomObject):
                 )
                 # Special case for backend
                 if backendClass is not None:
+                    try:
+                        # should pass with grid2op >= 1.7.1
+                        bk = backendClass(**backend_kwargs)
+                    except TypeError as exc_:
+                        # with grid2Op version prior to 1.7.1
+                        # you might have trouble with 
+                        # "TypeError: __init__() got an unexpected keyword argument 'can_be_copied'"
+                        msg_ = ("Impossible to create a backend for each mix using the "
+                                "backend key-word arguments. Falling back to creating "
+                                "with no argument at all (default behaviour with grid2op <= 1.7.0).")
+                        warnings.warn(msg_)
+                        bk = backendClass()
                     env = make(
                         env_path,
-                        backend=backendClass(),
+                        backend=bk,
                         _add_to_name=_add_to_name,
                         _compat_glop_version=_compat_glop_version,
                         test=_test,
