@@ -1,4 +1,4 @@
-from grid2op.Action import TopologyAndDispatchAction
+from grid2op.Action import PlayableAction
 from grid2op.Reward import RedispReward
 from grid2op.Rules import DefaultRules
 from grid2op.Chronics import Multifolder
@@ -7,7 +7,7 @@ from grid2op.Backend import PandaPowerBackend
 
 config = {
     "backend": PandaPowerBackend,
-    "action_class": TopologyAndDispatchAction,
+    "action_class": PlayableAction,
     "observation_class": None,
     "reward_class": RedispReward,
     "gamerules_class": DefaultRules,
@@ -15,26 +15,26 @@ config = {
     "grid_value_class": GridStateFromFileWithForecasts,
     "volagecontroler_class": None,
     "thermal_limits": [
-        541., 
-        450.,  
-        375.,  
-        636.,  
-        175.,  
-        285.,  
-        335.,  
-        657.,  
-        496.,
-        827.,  
-        442.,  
-        641.,  
-        840.,  
-        156.,  
-        664.,  
-        235.,  
-        119.,  
-        179.,
-        1986., 
-        1572.
+        541.0,
+        450.0,
+        375.0,
+        636.0,
+        175.0,
+        285.0,
+        335.0,
+        657.0,
+        496.0,
+        827.0,
+        442.0,
+        641.0,
+        840.0,
+        156.0,
+        664.0,
+        235.0,
+        119.0,
+        179.0,
+        1986.0,
+        1572.0,
     ],
-    "names_chronics_to_grid": None
+    "names_chronics_to_grid": None,
 }
